pub async fn connect_to_accessor_selector(
selector: Option<&str>,
query_proxy: &RealmQueryProxy,
) -> Result<ArchiveAccessorProxy, Error>Expand description
Connect to fuchsia.diagnostics.*ArchivistAccessor with the provided selector string.
The selector string can be in the form of “commands::utils::fuzzy_search_accessors for more
information.
If no selector string is provided, it will try to connect to
bootstrap/archivist:fuchsia.diagnostics.ArchiveAccessor.