pub struct ListAccessorsResult(/* private fields */);Trait Implementations
Sourceimpl Display for ListAccessorsResult
impl Display for ListAccessorsResult
Sourceimpl JsonSchema for ListAccessorsResult
impl JsonSchema for ListAccessorsResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ListAccessorsResult
impl RefUnwindSafe for ListAccessorsResult
impl Send for ListAccessorsResult
impl Sync for ListAccessorsResult
impl Unpin for ListAccessorsResult
impl UnsafeUnpin for ListAccessorsResult
impl UnwindSafe for ListAccessorsResult