pub struct SelectorsResult(/* private fields */);Trait Implementations
Sourceimpl Display for SelectorsResult
impl Display for SelectorsResult
Sourceimpl JsonSchema for SelectorsResult
impl JsonSchema for SelectorsResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SelectorsResult
impl RefUnwindSafe for SelectorsResult
impl Send for SelectorsResult
impl Sync for SelectorsResult
impl Unpin for SelectorsResult
impl UnsafeUnpin for SelectorsResult
impl UnwindSafe for SelectorsResult