pub struct ShowResult(/* private fields */);Trait Implementations
Sourceimpl Display for ShowResult
impl Display for ShowResult
Sourceimpl JsonSchema for ShowResult
impl JsonSchema for ShowResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ShowResult
impl RefUnwindSafe for ShowResult
impl Send for ShowResult
impl Sync for ShowResult
impl Unpin for ShowResult
impl UnsafeUnpin for ShowResult
impl UnwindSafe for ShowResult