pub struct ShowResultItem(/* private fields */);Methods from Deref<Target = InspectData>
Sourcepub fn msg(&self) -> Option<&str>
pub fn msg(&self) -> Option<&str>
Returns the string log associated with the message, if one exists.
Sourcepub fn payload_message(&self) -> Option<&DiagnosticsHierarchy<LogsField>>
pub fn payload_message(&self) -> Option<&DiagnosticsHierarchy<LogsField>>
If the log has message, returns an exclusive reference to it.
Sourcepub fn payload_keys(&self) -> Option<&DiagnosticsHierarchy<LogsField>>
pub fn payload_keys(&self) -> Option<&DiagnosticsHierarchy<LogsField>>
If the log has structured keys, returns an exclusive reference to them.
pub fn metadata(&self) -> &LogsMetadata
Sourcepub fn payload_keys_strings(
&self,
) -> Box<dyn Iterator<Item = String> + Send + '_>
pub fn payload_keys_strings( &self, ) -> Box<dyn Iterator<Item = String> + Send + '_>
Returns an iterator over the payload keys as strings with the format “key=value”.
Sourcepub fn file_path(&self) -> Option<&str>
pub fn file_path(&self) -> Option<&str>
Returns the file path associated with the message, if one exists.
Sourcepub fn line_number(&self) -> Option<&u64>
pub fn line_number(&self) -> Option<&u64>
Returns the line number associated with the message, if one exists.
Returns the tags associated with the message, if any exist.
Sourcepub fn dropped_logs(&self) -> Option<u64>
pub fn dropped_logs(&self) -> Option<u64>
Returns number of dropped logs if reported in the message.
Sourcepub fn rolled_out_logs(&self) -> Option<u64>
pub fn rolled_out_logs(&self) -> Option<u64>
Returns number of rolled out logs if reported in the message.
Sourcepub fn component_name_by_url(&self) -> Cow<'_, str>
pub fn component_name_by_url(&self) -> Cow<'_, str>
Returns a component name derived from the component URL if available and non-empty. Otherwise, it falls back to the component’s moniker. This name is intended for display purposes in logs, where showing the full URL or moniker might be impractical.
Sourcepub fn component_name(&self) -> Cow<'_, str>
pub fn component_name(&self) -> Cow<'_, str>
Returns the component name. This only makes sense for v1 components.